@@ -3,7 +3,10 @@ use {
     solana_measure::measure::Measure,
     solana_program_runtime::{
         instruction_recorder::InstructionRecorder,
-        invoke_context::{BuiltinProgram, Executors, InvokeContext, TransactionAccountRefCell},
+        invoke_context::{
+            BuiltinProgram, Executors, InvokeContext, ProcessInstructionResult,
+            TransactionAccountRefCell,
+        },
         log_collector::LogCollector,
         timings::ExecuteDetailsTimings,
     },
@@ -34,6 +37,13 @@ impl ::solana_frozen_abi::abi_example::AbiExample for MessageProcessor {
     }
 }
 
+/// Resultant information gathered from calling process_message()
+#[derive(Debug, Default, Clone, Copy, PartialEq, Eq)]
+pub struct ProcessedMessageInfo {
+    /// The amount that the accounts data len has changed
+    pub accounts_data_len_delta: i64,
+}
+
 impl MessageProcessor {
     /// Process a message.
     /// This method calls each instruction in the message over the set of loaded accounts.
@@ -56,7 +66,7 @@ impl MessageProcessor {
         sysvars: &[(Pubkey, Vec<u8>)],
         blockhash: Hash,
         lamports_per_signature: u64,
-    ) -> Result<(), TransactionError> {
+    ) -> Result<ProcessedMessageInfo, TransactionError> {
         let mut invoke_context = InvokeContext::new(
             rent,
             accounts,
@@ -105,18 +115,22 @@ impl MessageProcessor {
                     Some(&instruction_recorders[instruction_index]);
             }
             let mut time = Measure::start("execute_instruction");
-            let compute_meter_consumption = invoke_context
-                .process_instruction(message, instruction, program_indices, &[], &[])
-                .map_err(|err| TransactionError::InstructionError(instruction_index as u8, err))?;
+            let ProcessInstructionResult {
+                compute_units_consumed,
+                result,
+            } = invoke_context.process_instruction(message, instruction, program_indices, &[], &[]);
             time.stop();
             timings.accumulate_program(
                 instruction.program_id(&message.account_keys),
                 time.as_us(),
-                compute_meter_consumption,
+                compute_units_consumed,
+                result.is_err(),
             );
             timings.accumulate(&invoke_context.timings);
+            result
+                .map_err(|err| TransactionError::InstructionError(instruction_index as u8, err))?;
         }
-        Ok(())
+        Ok(ProcessedMessageInfo::default())
     }
 }
 
@@ -242,7 +256,7 @@ mod tests {
             Hash::default(),
             0,
         );
-        assert_eq!(result, Ok(()));
+        assert!(result.is_ok());
         assert_eq!(accounts[0].1.borrow().lamports(), 100);
         assert_eq!(accounts[1].1.borrow().lamports(), 0);
 
@@ -481,7 +495,7 @@ mod tests {
             Hash::default(),
             0,
         );
-        assert_eq!(result, Ok(()));
+        assert!(result.is_ok());
 
         // Do work on the same account but at different location in keyed_accounts[]
         let message = Message::new(
@@ -511,7 +525,7 @@ mod tests {
             Hash::default(),
             0,
         );
-        assert_eq!(result, Ok(()));
+        assert!(result.is_ok());
         assert_eq!(accounts[0].1.borrow().lamports(), 80);
         assert_eq!(accounts[1].1.borrow().lamports(), 20);
         assert_eq!(accounts[0].1.borrow().data(), &vec![42]);
